(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('prop-types'), require('helix-ui')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', 'prop-types', 'helix-ui'], factory) :
  (global = global || self, factory(global.HelixReact = {}, global.react, global.propTypes, global.helixUi));
}(this, (function (exports, React, PropTypes, HelixUI) {
  var React__default = 'default' in React ? React['default'] : React;
  PropTypes = PropTypes && Object.prototype.hasOwnProperty.call(PropTypes, 'default') ? PropTypes['default'] : PropTypes;
  HelixUI = HelixUI && Object.prototype.hasOwnProperty.call(HelixUI, 'default') ? HelixUI['default'] : HelixUI;

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends.apply(this, arguments);
  }

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  /**
   * @see https://laptrinhx.com/reusing-the-ref-from-forwardref-with-react-hooks-3215655428/
   * @param refs
   * @return {React.MutableRefObject}
   */

  function useCombinedRefs() {
    var refs = [].slice.call(arguments);
    var targetRef = React__default.useRef();
    React__default.useEffect(function () {
      refs.forEach(function (ref) {
        if (!ref) return;

        if (typeof ref === 'function') {
          ref(targetRef.current);
        } else {
          ref.current = targetRef.current;
        }
      });
    }, [refs]);
    return targetRef;
  }

  var handlerNameToEvent = function handlerNameToEvent(handlerName) {
    return handlerName.replace(/^on/, '').toLowerCase();
  };
  /**
   * Adds event handlers like onOpen or onClose to event listeners: 'open' or 'close'
   * @param {object} eventHandlers such as onClose, onOpen, ...etc
   * @param {React.MutableRefObject} ref
   * @return {React.MutableRefObject}
   */


  function useEventListener(eventHandlers, ref) {
    if (eventHandlers === void 0) {
      eventHandlers = {};
    }

    var theRef = ref ? useCombinedRefs(ref, React.useRef(null)) : React.useRef(null);
    React.useEffect(function () {
      Object.entries(eventHandlers).forEach(function (_ref) {
        var handlerName = _ref[0],
            eventHandler = _ref[1];
        theRef.current.addEventListener(handlerNameToEvent(handlerName), eventHandler);
      });
      return function () {
        Object.entries(eventHandlers).forEach(function (_ref2) {
          var handlerName = _ref2[0],
              eventHandler = _ref2[1];
          theRef.current.removeEventListener(handlerNameToEvent(handlerName), eventHandler);
        });
      };
    }, []);
    return theRef;
  }

  var Alert = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var className = _ref.className,
        children = _ref.children,
        onDismiss = _ref.onDismiss,
        onSubmit = _ref.onSubmit,
        rest = _objectWithoutPropertiesLoose(_ref, ["onOpen", "onClose", "className", "children", "onDismiss", "onSubmit"]);

    var hxRef = useEventListener({
      onDismiss: onDismiss,
      onSubmit: onSubmit
    }, ref);
    return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("hx-alert", _extends({
      "class": className,
      ref: hxRef
    }, rest), children));
  });
  Alert.displayName = 'Alert';
  Alert.propTypes = {
    className: PropTypes.string,
    children: PropTypes.node.isRequired,
    type: PropTypes.string,
    status: PropTypes.string,
    cta: PropTypes.string,
    persist: PropTypes.bool,
    onDismiss: PropTypes.func,
    onSubmit: PropTypes.func
  };

  var Icon = function Icon(_ref) {
    var type = _ref.type,
        className = _ref.className,
        rest = _objectWithoutPropertiesLoose(_ref, ["type", "className"]);

    return /*#__PURE__*/React__default.createElement("hx-icon", _extends({
      type: type
    }, rest, {
      "class": className
    }));
  };

  Icon.propTypes = {
    type: PropTypes.string,
    className: PropTypes.string
  };

  var Busy = function Busy(_ref) {
    var className = _ref.className,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "children"]);

    return /*#__PURE__*/React__default.createElement("hx-busy", _extends({
      "class": className
    }, rest));
  };

  Busy.propTypes = {
    paused: PropTypes.bool,
    className: PropTypes.string
  };

  function cssFor(modifier) {
    return {
      large: 'hxLg',
      primary: 'hxPrimary',
      small: 'hxSm',
      tertiary: 'hxTertiary'
    }[modifier];
  }

  function classNames(props) {
    return ['hxBtn', cssFor(props.variant), cssFor(props.size), props.className].join(' ').trim();
  }

  var Button = /*#__PURE__*/function (_React$Component) {
    _inheritsLoose(Button, _React$Component);

    function Button() {
      return _React$Component.apply(this, arguments) || this;
    }

    var _proto = Button.prototype;

    _proto.render = function render() {
      // destructure props for JSX composition
      var _this$props = this.props,
          busy = _this$props.busy,
          children = _this$props.children,
          headIcon = _this$props.headIcon,
          tailIcon = _this$props.tailIcon,
          type = _this$props.type,
          props = _objectWithoutPropertiesLoose(_this$props, ["busy", "children", "className", "headIcon", "size", "tailIcon", "type", "variant"]);

      return /*#__PURE__*/React__default.createElement("button", _extends({
        className: classNames(this.props),
        type: type || 'button'
      }, props), headIcon && /*#__PURE__*/React__default.createElement(Icon, {
        type: headIcon
      }), children && /*#__PURE__*/React__default.createElement("span", null, children), busy ? /*#__PURE__*/React__default.createElement(Busy, null) : tailIcon && /*#__PURE__*/React__default.createElement(Icon, {
        type: tailIcon
      }));
    };

    return Button;
  }(React__default.Component);

  Button.propTypes = {
    busy: PropTypes.bool,
    disabled: PropTypes.bool,
    headIcon: PropTypes.string,
    size: PropTypes.string,
    tailIcon: PropTypes.string,
    type: PropTypes.string,
    variant: PropTypes.string
  };

  var Breadcrumb = function Breadcrumb(_ref) {
    var children = _ref.children,
        _ref$icon = _ref.icon,
        icon = _ref$icon === void 0 ? 'angle-right' : _ref$icon,
        _ref$addDelimiter = _ref.addDelimiter,
        addDelimiter = _ref$addDelimiter === void 0 ? true : _ref$addDelimiter,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "icon", "addDelimiter"]);

    // Automatically add delimiter
    var kids = children.length > 0 ? children.map(function (child, index) {
      return [child, addDelimiter && index + 1 < children.length && /*#__PURE__*/React__default.createElement("hx-icon", {
        key: index,
        "class": "delimiter",
        type: icon
      })];
    }) : children;
    return /*#__PURE__*/React__default.createElement("nav", _extends({
      className: "hxBreadcrumb"
    }, rest), kids);
  };

  Breadcrumb.propTypes = {
    icon: PropTypes.string,
    children: PropTypes.node
  };

  var Checkbox = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var id = _ref.id,
        label = _ref.label,
        indeterminate = _ref.indeterminate,
        className = _ref.className,
        rest = _objectWithoutPropertiesLoose(_ref, ["id", "label", "indeterminate", "className", "style"]);

    var hxRef = useCombinedRefs(ref, React.useRef());
    React.useEffect(function () {
      hxRef.current.indeterminate = indeterminate;
    }, [indeterminate]);
    return /*#__PURE__*/React__default.createElement("hx-checkbox-control", {
      "class": className
    }, /*#__PURE__*/React__default.createElement("input", _extends({
      ref: hxRef
    }, rest, {
      id: id,
      type: "checkbox"
    })), /*#__PURE__*/React__default.createElement("label", {
      htmlFor: id
    }, /*#__PURE__*/React__default.createElement("hx-checkbox", null), label));
  });
  Checkbox.displayName = 'Checkbox';
  Checkbox.propTypes = {
    className: PropTypes.string,
    style: PropTypes.object,
    checked: PropTypes.bool,
    id: PropTypes.string.isRequired,
    disabled: PropTypes.bool,
    indeterminate: PropTypes.bool,
    required: PropTypes.bool,
    label: PropTypes.string,
    name: PropTypes.string,
    onChange: PropTypes.func
  };

  function createCommonjsModule(fn, basedir, module) {
  	return module = {
  	  path: basedir,
  	  exports: {},
  	  require: function (path, base) {
        return commonjsRequire();
      }
  	}, fn(module, module.exports), module.exports;
  }

  function commonjsRequire () {
  	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
  }

  var classnames = createCommonjsModule(function (module) {
  /*!
    Copyright (c) 2017 Jed Watson.
    Licensed under the MIT License (MIT), see
    http://jedwatson.github.io/classnames
  */
  /* global define */

  (function () {

  	var hasOwn = {}.hasOwnProperty;

  	function classNames () {
  		var classes = [];

  		for (var i = 0; i < arguments.length; i++) {
  			var arg = arguments[i];
  			if (!arg) continue;

  			var argType = typeof arg;

  			if (argType === 'string' || argType === 'number') {
  				classes.push(arg);
  			} else if (Array.isArray(arg) && arg.length) {
  				var inner = classNames.apply(null, arg);
  				if (inner) {
  					classes.push(inner);
  				}
  			} else if (argType === 'object') {
  				for (var key in arg) {
  					if (hasOwn.call(arg, key) && arg[key]) {
  						classes.push(key);
  					}
  				}
  			}
  		}

  		return classes.join(' ');
  	}

  	if ( module.exports) {
  		classNames.default = classNames;
  		module.exports = classNames;
  	} else {
  		window.classNames = classNames;
  	}
  }());
  });

  var SIZES = {
    small: 'hxSm',
    medium: 'hxMd',
    large: 'hxLg'
  };
  var POSITIONS = ['top-left', 'top-center', 'top-right', 'right-top', 'right-middle', 'right-bottom', 'bottom-right', 'bottom-center', 'bottom-left', 'left-bottom', 'left-middle', 'left-top'];

  /**
   * Because Web components attributes convert booleans to strings
   * this stops values like false from being converted to "false" and then evaluating as true.
   * @param {boolean} bool
   * @return {*}
   */
  var wcBool = function wcBool(bool) {
    return bool ? true : null;
  };

  var ChoiceTile = function ChoiceTile(_ref) {
    var _classNames;

    var checked = _ref.checked,
        children = _ref.children,
        className = _ref.className,
        disabled = _ref.disabled,
        icon = _ref.icon,
        invalid = _ref.invalid,
        name = _ref.name,
        onChange = _ref.onChange,
        size = _ref.size,
        subdued = _ref.subdued,
        title = _ref.title,
        style = _ref.style,
        radioInput = _ref.radioInput,
        rest = _objectWithoutPropertiesLoose(_ref, ["checked", "children", "className", "disabled", "icon", "invalid", "name", "onChange", "size", "subdued", "title", "style", "radioInput"]);

    return /*#__PURE__*/React__default.createElement("label", {
      className: classnames({
        hxChoice: true
      }, className),
      style: style
    }, radioInput ? radioInput : /*#__PURE__*/React__default.createElement("input", _extends({
      checked: wcBool(checked),
      disabled: disabled,
      invalid: invalid == null ? void 0 : invalid.toString(),
      name: name,
      onChange: onChange,
      type: "radio"
    }, rest)), /*#__PURE__*/React__default.createElement("hx-tile", {
      "class": classnames((_classNames = {
        hxSubdued: subdued
      }, _classNames[SIZES[size]] = true, _classNames))
    }, /*#__PURE__*/React__default.createElement("hx-icon", {
      type: "checkmark"
    }), icon && /*#__PURE__*/React__default.createElement("div", {
      className: "hx-tile-icon"
    }, /*#__PURE__*/React__default.createElement("hx-icon", {
      type: icon
    })), /*#__PURE__*/React__default.createElement("header", null, title), children));
  };

  ChoiceTile.propTypes = {
    checked: PropTypes.bool.isRequired,
    children: PropTypes.node,
    className: PropTypes.string,
    style: PropTypes.object,
    disabled: PropTypes.bool,
    icon: PropTypes.string,
    invalid: PropTypes.bool,
    name: PropTypes.string,
    onChange: PropTypes.func,
    size: PropTypes.oneOf(Object.keys(SIZES)),
    subdued: PropTypes.bool,
    title: PropTypes.string.isRequired,
    radioInput: PropTypes.node
  };
  ChoiceTile.defaultProps = {
    checked: false,
    size: 'medium'
  };

  var Disclosure = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var className = _ref.className,
        ariaControls = _ref.ariaControls,
        ariaExpanded = _ref.ariaExpanded,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "ariaControls", "ariaExpanded"]);

    return /*#__PURE__*/React__default.createElement("hx-disclosure", _extends({
      ref: ref,
      "class": className,
      "aria-controls": ariaControls,
      "aria-expanded": wcBool(ariaExpanded)
    }, rest));
  });
  Disclosure.propTypes = {
    ariaControls: PropTypes.string.isRequired,
    ariaExpanded: PropTypes.bool,
    role: PropTypes.string,
    tabindex: PropTypes.string,
    className: PropTypes.string,
    children: PropTypes.node.isRequired
  };
  Disclosure.displayName = 'Disclosure';

  var Div = function Div(_ref) {
    var className = _ref.className,
        rest = _objectWithoutPropertiesLoose(_ref, ["className"]);

    return /*#__PURE__*/React__default.createElement("hx-div", _extends({
      "class": className
    }, rest));
  };

  Div.propTypes = {
    className: PropTypes.string,
    children: PropTypes.node.isRequired,
    scroll: PropTypes.oneOf(['vertical', 'horizontal', 'both', 'none'])
  };

  var Drawer = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var children = _ref.children,
        className = _ref.className,
        id = _ref.id,
        onClose = _ref.onClose,
        onOpen = _ref.onOpen,
        open = _ref.open,
        size = _ref.size,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "className", "id", "onClose", "onOpen", "open", "size"]);

    var hxRef = useEventListener({
      onOpen: onOpen,
      onClose: onClose
    }, ref);
    return /*#__PURE__*/React__default.createElement("hx-drawer", _extends({
      "class": classnames(className, SIZES[size]),
      id: id,
      open: wcBool(open),
      ref: hxRef
    }, rest), children);
  });
  Drawer.displayName = 'Drawer';
  Drawer.propTypes = {
    className: PropTypes.string,
    id: PropTypes.string.isRequired,
    onClose: PropTypes.func,
    onOpen: PropTypes.func,
    open: PropTypes.bool,
    size: PropTypes.oneOf(Object.keys(SIZES))
  };
  Drawer.defaultProps = {
    open: null
  };

  var Modal = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var onOpen = _ref.onOpen,
        onClose = _ref.onClose,
        className = _ref.className,
        open = _ref.open,
        size = _ref.size,
        children = _ref.children,
        rest = _objectWithoutPropertiesLoose(_ref, ["onOpen", "onClose", "className", "open", "size", "children"]);

    var hxRef = useEventListener({
      onOpen: onOpen,
      onClose: onClose
    }, ref);
    return /*#__PURE__*/React__default.createElement("hx-modal", _extends({
      "class": classnames(className, SIZES[size]),
      ref: hxRef,
      open: wcBool(open)
    }, rest), children);
  });
  Modal.displayName = 'Modal';
  Modal.propTypes = {
    id: PropTypes.string,
    size: PropTypes.oneOf(Object.keys(SIZES)),
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    open: PropTypes.bool,
    onClose: PropTypes.func,
    onOpen: PropTypes.func
  };

  var Pill = function Pill(_ref) {
    var className = _ref.className,
        children = _ref.children,
        onDismiss = _ref.onDismiss,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "children", "onDismiss"]);

    var hxRef = useEventListener({
      onDismiss: onDismiss
    });
    return /*#__PURE__*/React__default.createElement("hx-pill", _extends({
      "class": className
    }, rest, {
      ref: hxRef
    }), children);
  };

  Pill.propTypes = {
    persist: PropTypes.bool,
    onDismiss: PropTypes.func
  };

  var Progress = function Progress(_ref) {
    var className = _ref.className,
        value = _ref.value,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "children", "value"]);

    return /*#__PURE__*/React__default.createElement("hx-progress", _extends({
      "class": className
    }, rest, {
      value: value.toString()
    }));
  };

  Progress.propTypes = {
    value: PropTypes.number,
    className: PropTypes.string
  };

  var PILL_VARIANTS = {
    grey: 'hxEmphasisGray',
    purple: 'hxEmphasisPurple',
    subdued: 'hxSubdued'
  };

  var Status = function Status(_ref) {
    var className = _ref.className,
        children = _ref.children,
        variant = _ref.variant,
        filled = _ref.filled,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "children", "variant", "filled"]);

    return /*#__PURE__*/React__default.createElement("hx-status", _extends({
      "class": classnames(className, PILL_VARIANTS[variant], {
        hxFill: filled
      })
    }, rest), children);
  };

  Status.propTypes = {
    variant: PropTypes.oneOf(Object.keys(PILL_VARIANTS)),
    filled: PropTypes.bool
  };

  var Popover = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var onOpen = _ref.onOpen,
        onClose = _ref.onClose,
        onReposition = _ref.onReposition,
        className = _ref.className,
        open = _ref.open,
        children = _ref.children,
        relativeTo = _ref.relativeTo,
        rest = _objectWithoutPropertiesLoose(_ref, ["onOpen", "onClose", "onReposition", "className", "open", "children", "relativeTo"]);

    var hxRef = useEventListener({
      onOpen: onOpen,
      onClose: onClose,
      onReposition: onReposition
    }, ref);
    return /*#__PURE__*/React__default.createElement("hx-popover", _extends({
      "class": classnames(className),
      ref: hxRef,
      open: wcBool(open),
      "relative-to": relativeTo
    }, rest), children);
  });
  Popover.displayName = 'Popover';
  Popover.propTypes = {
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    id: PropTypes.string,
    position: PropTypes.oneOf(POSITIONS),
    relativeTo: PropTypes.string,
    open: PropTypes.bool,
    onClose: PropTypes.func,
    onOpen: PropTypes.func,
    onReposition: PropTypes.func
  };

  var Radio = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var id = _ref.id,
        label = _ref.label,
        className = _ref.className,
        style = _ref.style,
        rest = _objectWithoutPropertiesLoose(_ref, ["id", "label", "className", "style"]);

    return /*#__PURE__*/React__default.createElement("hx-radio-control", {
      "class": className,
      style: style,
      ref: ref
    }, /*#__PURE__*/React__default.createElement("input", _extends({}, rest, {
      id: id,
      type: "radio"
    })), /*#__PURE__*/React__default.createElement("label", {
      htmlFor: id
    }, /*#__PURE__*/React__default.createElement("hx-radio", null), label));
  });
  Radio.propTypes = {
    label: PropTypes.string.isRequired,
    className: PropTypes.string,
    style: PropTypes.object,
    checked: PropTypes.bool,
    id: PropTypes.string.isRequired,
    disabled: PropTypes.bool,
    required: PropTypes.bool,
    name: PropTypes.string,
    onChange: PropTypes.func
  };
  Radio.displayName = 'Radio';

  var RadioSet = function RadioSet(_ref) {
    var className = _ref.className,
        children = _ref.children,
        rest = _objectWithoutPropertiesLoose(_ref, ["className", "children"]);

    return /*#__PURE__*/React__default.createElement("hx-radio-set", _extends({
      "class": className
    }, rest), children);
  };

  RadioSet.propTypes = {
    children: PropTypes.node
  };

  /**
   * Identical to React.useEffect, except that it never runs on mount. This is the equivalent of
   * the componentDidUpdate lifecycle function.
   * @see https://stackoverflow.com/questions/53253940/make-react-useeffect-hook-not-run-on-initial-render
   * @param {function:function} effect - A useEffect effect.
   * @param {array} dependencies - useEffect dependency list.
   */

  var useEffectExceptOnMount = function useEffectExceptOnMount(effect, dependencies) {
    var mounted = React__default.useRef(false);
    React__default.useEffect(function () {
      if (mounted.current) {
        var unmount = effect();
        return function () {
          return unmount && unmount();
        };
      } else {
        mounted.current = true;
      }
    }, dependencies);
    React__default.useEffect(function () {
      return function () {
        return mounted.current = false;
      };
    }, []);
  };

  /**
   * @see https://helixdesignsystem.github.io/helix-ui/components/search/
   */

  var Search = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var disabled = _ref.disabled,
        id = _ref.id,
        label = _ref.label,
        className = _ref.className,
        clearLabel = _ref.clearLabel,
        onClear = _ref.onClear,
        optional = _ref.optional,
        required = _ref.required,
        containerId = _ref.containerId,
        value = _ref.value,
        style = _ref.style,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "disabled", "id", "label", "className", "clearLabel", "onClear", "optional", "required", "containerId", "value", "style"]);

    /**
     * Show clear icon when value changes programmatically by triggering 'input' event manually.
     * @see https://stackoverflow.com/questions/23892547/what-is-the-best-way-to-trigger-onchange-event-in-react-js
     */
    var inputRef = React.useRef();
    useEffectExceptOnMount(function () {
      var input = inputRef.current;
      var nativeInputValueSetter = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
      nativeInputValueSetter.call(input, value);
      var ev = new Event('input', {
        bubbles: true
      });
      input.dispatchEvent(ev);
    }, [value]);
    return /*#__PURE__*/React__default.createElement("hx-search-control", {
      "class": className,
      id: containerId,
      style: style,
      ref: ref
    }, /*#__PURE__*/React__default.createElement("input", _extends({
      id: id,
      value: value,
      ref: inputRef
    }, rest, {
      disabled: wcBool(disabled),
      type: "search"
    })), /*#__PURE__*/React__default.createElement("button", {
      type: "button",
      className: "hxClear",
      "aria-label": clearLabel,
      hidden: true,
      onClick: onClear
    }, /*#__PURE__*/React__default.createElement(Icon, {
      type: "times"
    })), /*#__PURE__*/React__default.createElement("hx-search", null), label && /*#__PURE__*/React__default.createElement("label", {
      className: classnames({
        hxOptional: optional,
        hxRequired: required
      }),
      htmlFor: id
    }, label));
  });
  Search.displayName = 'Search';
  Search.propTypes = {
    className: PropTypes.string,
    style: PropTypes.object,
    clearLabel: PropTypes.string,
    label: PropTypes.string,
    id: PropTypes.string.isRequired,
    containerId: PropTypes.string,
    disabled: PropTypes.bool,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onClear: PropTypes.func,
    optional: PropTypes.bool,
    required: PropTypes.bool
  };
  Search.defaultProps = {
    clearLabel: 'Clear search'
  };

  /**
   * @see https://helixdesignsystem.github.io/helix-ui/elements/hx-search-assistance/
   */

  var SearchAssistance = function SearchAssistance(_ref) {
    var children = _ref.children,
        className = _ref.className,
        relativeTo = _ref.relativeTo,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "className", "relativeTo"]);

    return /*#__PURE__*/React__default.createElement("hx-search-assistance", _extends({
      "class": className,
      "relative-to": relativeTo
    }, rest), children);
  };

  SearchAssistance.propTypes = {
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    relativeTo: PropTypes.string.isRequired,
    position: PropTypes.oneOf(POSITIONS)
  };

  var supportsPassiveEvents;
  function arePassiveEventsSupported() {
    if (supportsPassiveEvents !== undefined) {
      return supportsPassiveEvents;
    }

    var passive = false;
    var options = {
      // @ts-ignore: this is a temporary object, it doesn't have to return anything
      get passive() {
        passive = true;
      }

    };

    var noop = function noop() {};

    window.addEventListener('t', noop, options);
    window.removeEventListener('t', noop, options);
    supportsPassiveEvents = passive;
    return passive;
  }

  var index =  React.useLayoutEffect ;

  var useLatest = function useLatest(value) {
    var ref = React.useRef(value);
    index(function () {
      ref.current = value;
    });
    return ref;
  };

  var MOUSEDOWN = 'mousedown';
  var TOUCHSTART = 'touchstart';
  var events = [MOUSEDOWN, TOUCHSTART];

  var getOptions = function getOptions(event) {
    if (event !== TOUCHSTART) {
      return;
    }

    if (arePassiveEventsSupported()) {
      return {
        passive: true
      };
    }
  };

  function useOnClickOutside(ref, handler) {

    var handlerRef = useLatest(handler);
    React.useEffect(function () {
      if (!handler) {
        return;
      }

      var listener = function listener(event) {
        if (!ref.current || !handlerRef.current || ref.current.contains(event.target)) {
          return;
        }

        handlerRef.current(event);
      };

      events.forEach(function (event) {
        document.addEventListener(event, listener, getOptions(event));
      });
      return function () {
        events.forEach(function (event) {
          document.removeEventListener(event, listener, getOptions(event));
        });
      };
    }, [!handler]);
  }

  /**
   * @see https://helixdesignsystem.github.io/helix-ui/components/search/
   */

  var SearchAssist = function SearchAssist(_ref) {
    var children = _ref.children,
        _onFocus = _ref.onFocus,
        position = _ref.position,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "onFocus", "onBlur", "position"]);

    var _useState = React.useState(false),
        open = _useState[0],
        setOpen = _useState[1];

    var searchRef = React.useRef();
    useOnClickOutside(searchRef, function () {
      return setOpen(false);
    });
    var hasChildren = React__default.Children.toArray(children).filter(function (c) {
      return c;
    }).length > 0;
    return /*#__PURE__*/React__default.createElement("div", {
      ref: searchRef
    }, /*#__PURE__*/React__default.createElement(Search, _extends({}, rest, {
      onFocus: function onFocus(e) {
        setOpen(true);
        _onFocus && _onFocus(e);
      },
      containerId: rest.id + "-hx-search-control"
    })), hasChildren && /*#__PURE__*/React__default.createElement(SearchAssistance, {
      relativeTo: rest.id + "-hx-search-control",
      open: wcBool(open),
      position: position,
      onClick: function onClick() {
        return setOpen(false);
      }
    }, children));
  };

  SearchAssist.propTypes = {
    children: PropTypes.node.isRequired,
    position: PropTypes.oneOf(POSITIONS),
    className: PropTypes.string,
    clearLabel: PropTypes.string,
    label: PropTypes.string,
    id: PropTypes.string.isRequired,
    disabled: PropTypes.bool,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onClear: PropTypes.func,
    optional: PropTypes.bool,
    required: PropTypes.bool
  };

  var Select = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var children = _ref.children,
        className = _ref.className,
        disabled = _ref.disabled,
        id = _ref.id,
        label = _ref.label,
        onChange = _ref.onChange,
        optional = _ref.optional,
        required = _ref.required,
        style = _ref.style,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "className", "disabled", "id", "label", "onChange", "optional", "required", "style"]);

    return /*#__PURE__*/React__default.createElement("hx-select-control", {
      "class": className,
      style: style,
      ref: ref
    }, /*#__PURE__*/React__default.createElement("select", _extends({
      id: id,
      disabled: disabled,
      onChange: onChange,
      required: required
    }, rest), children), /*#__PURE__*/React__default.createElement("hx-select", null), label && /*#__PURE__*/React__default.createElement("label", {
      className: classnames({
        hxOptional: optional,
        hxRequired: required
      }),
      htmlFor: id
    }, label));
  });
  Select.displayName = 'Select';
  Select.propTypes = {
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    style: PropTypes.object,
    disabled: PropTypes.bool,
    id: PropTypes.string.isRequired,
    label: PropTypes.string,
    onChange: PropTypes.func.isRequired,
    optional: PropTypes.bool,
    required: PropTypes.bool
  };

  var Switch = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var id = _ref.id,
        className = _ref.className,
        onLabel = _ref.onLabel,
        offLabel = _ref.offLabel,
        invalid = _ref.invalid,
        rest = _objectWithoutPropertiesLoose(_ref, ["id", "className", "onLabel", "offLabel", "invalid"]);

    return /*#__PURE__*/React__default.createElement("hx-switch-control", {
      "class": classnames('switch', className),
      ref: ref
    }, /*#__PURE__*/React__default.createElement("input", _extends({
      type: "checkbox",
      id: id
    }, rest, {
      invalid: invalid == null ? void 0 : invalid.toString()
    })), /*#__PURE__*/React__default.createElement("label", {
      htmlFor: id
    }, /*#__PURE__*/React__default.createElement("hx-switch", {
      onlabel: onLabel,
      offlabel: offLabel,
      "aria-labelledby": id
    })));
  });
  Switch.propTypes = {
    id: PropTypes.string.isRequired,
    onLabel: PropTypes.string,
    offLabel: PropTypes.string,
    className: PropTypes.string,
    disabled: PropTypes.bool,
    invalid: PropTypes.bool,
    label: PropTypes.bool,
    name: PropTypes.string,
    onChange: PropTypes.func
  };
  Switch.defaultProps = {
    onLabel: '',
    offLabel: ''
  };
  Switch.displayName = 'Switch';

  var Text = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var id = _ref.id,
        label = _ref.label,
        invalid = _ref.invalid,
        className = _ref.className,
        required = _ref.required,
        optional = _ref.optional,
        children = _ref.children,
        prefix = _ref.prefix,
        suffix = _ref.suffix,
        style = _ref.style,
        rest = _objectWithoutPropertiesLoose(_ref, ["id", "label", "invalid", "className", "required", "optional", "children", "prefix", "suffix", "style"]);

    return /*#__PURE__*/React__default.createElement("hx-text-control", {
      "class": classnames(className, {
        hxInvalid: invalid
      }),
      style: style,
      ref: ref
    }, /*#__PURE__*/React__default.createElement("input", _extends({}, rest, {
      id: id,
      required: required,
      type: "text"
    })), label && /*#__PURE__*/React__default.createElement("label", {
      className: classnames({
        hxOptional: optional,
        hxRequired: required
      }),
      htmlFor: id
    }, label), prefix && /*#__PURE__*/React__default.createElement("span", {
      className: "hxPrefix"
    }, prefix), suffix && /*#__PURE__*/React__default.createElement("span", {
      className: "hxSuffix"
    }, suffix), children);
  });
  Text.displayName = 'Text';
  Text.propTypes = {
    id: PropTypes.string.isRequired,
    className: PropTypes.string,
    style: PropTypes.object,
    children: PropTypes.node,
    optional: PropTypes.bool,
    disabled: PropTypes.bool,
    invalid: PropTypes.bool,
    required: PropTypes.bool,
    label: PropTypes.string,
    name: PropTypes.string,
    prefix: PropTypes.node,
    suffix: PropTypes.node,
    onChange: PropTypes.func
  };

  var TextArea = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var id = _ref.id,
        label = _ref.label,
        className = _ref.className,
        required = _ref.required,
        disabled = _ref.disabled,
        optional = _ref.optional,
        invalid = _ref.invalid,
        children = _ref.children,
        style = _ref.style,
        rest = _objectWithoutPropertiesLoose(_ref, ["id", "label", "className", "required", "disabled", "optional", "invalid", "children", "style"]);

    return /*#__PURE__*/React__default.createElement("hx-textarea-control", {
      "class": classnames(className, {
        hxInvalid: invalid
      }),
      style: style,
      ref: ref
    }, /*#__PURE__*/React__default.createElement("textarea", _extends({}, rest, {
      id: id,
      required: required,
      disabled: disabled
    })), label && /*#__PURE__*/React__default.createElement("label", {
      className: classnames({
        hxOptional: optional,
        hxRequired: required
      }),
      htmlFor: id
    }, label), children);
  });
  TextArea.displayName = 'TextArea';
  TextArea.propTypes = {
    id: PropTypes.string.isRequired,
    className: PropTypes.string,
    style: PropTypes.object,
    children: PropTypes.node,
    optional: PropTypes.bool,
    disabled: PropTypes.bool,
    required: PropTypes.bool,
    invalid: PropTypes.bool,
    label: PropTypes.bool,
    name: PropTypes.string,
    onChange: PropTypes.func
  };

  var Toast = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var className = _ref.className,
        children = _ref.children,
        onDismiss = _ref.onDismiss,
        onSubmit = _ref.onSubmit,
        rest = _objectWithoutPropertiesLoose(_ref, ["onOpen", "onClose", "className", "children", "onDismiss", "onSubmit"]);

    var hxRef = useEventListener({
      onDismiss: onDismiss,
      onSubmit: onSubmit
    }, ref);
    return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("hx-toast", _extends({
      "class": className,
      ref: hxRef
    }, rest), children));
  });
  Toast.displayName = 'Toast';
  Toast.propTypes = {
    className: PropTypes.string,
    children: PropTypes.node.isRequired,
    type: PropTypes.oneOf(['info', 'error', 'success']),
    cta: PropTypes.string,
    onDismiss: PropTypes.func,
    onSubmit: PropTypes.func
  };

  var Tooltip = /*#__PURE__*/React__default.forwardRef(function (_ref, ref) {
    var children = _ref.children,
        id = _ref.id,
        position = _ref.position,
        onClose = _ref.onClose,
        onOpen = _ref.onOpen,
        onReposition = _ref.onReposition,
        rest = _objectWithoutPropertiesLoose(_ref, ["children", "id", "position", "onClose", "onOpen", "onReposition"]);

    var hxRef = useEventListener({
      onClose: onClose,
      onOpen: onOpen,
      onReposition: onReposition
    }, ref);
    return /*#__PURE__*/React__default.createElement("hx-tooltip", _extends({
      "for": id,
      position: position,
      ref: hxRef
    }, rest), children);
  });
  Tooltip.displayName = 'Tooltip';
  Tooltip.propTypes = {
    children: PropTypes.node.isRequired,
    id: PropTypes.string.isRequired,
    position: PropTypes.oneOf(POSITIONS),
    relativeTo: PropTypes.string,
    htmlFor: PropTypes.string
  };
  Tooltip.defaultProps = {
    position: 'top-left'
  };

  exports.Alert = Alert;
  exports.Breadcrumb = Breadcrumb;
  exports.Busy = Busy;
  exports.Button = Button;
  exports.Checkbox = Checkbox;
  exports.ChoiceTile = ChoiceTile;
  exports.Disclosure = Disclosure;
  exports.Div = Div;
  exports.Drawer = Drawer;
  exports.Icon = Icon;
  exports.Modal = Modal;
  exports.Pill = Pill;
  exports.Popover = Popover;
  exports.Progress = Progress;
  exports.Radio = Radio;
  exports.RadioSet = RadioSet;
  exports.Search = Search;
  exports.SearchAssist = SearchAssist;
  exports.Select = Select;
  exports.Status = Status;
  exports.Switch = Switch;
  exports.Text = Text;
  exports.TextArea = TextArea;
  exports.Toast = Toast;
  exports.Tooltip = Tooltip;

})));
